WxContinuousRectangleBorder class

A rectangular border with smooth continuous transitions between the straight sides and the rounded corners.

{@tool snippet}

Widget build(BuildContext context) {
  return Material(
    shape: ContinuousRectangleBorder(
      borderRadius: BorderRadius.circular(28.0),
    ),
  );
}

{@end-tool}

See also:

Inheritance

Constructors

WxContinuousRectangleBorder({WxBorderSide? side, Color? color, Gradient? gradient, double? offset, WxBorderStyle? style, double? width, BorderRadiusGeometry corners = BorderRadius.zero})
Creates a ContinuousRectangleBorder.
const

Properties

color → Color?
The color of the outline, if specified. Can be overridden by gradient.
finalinherited
corners → BorderRadiusGeometry
The radii for each corner.
finalinherited
dimensions → EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setter
effectiveSide → WxBorderSide
Returns the effective WxBorderSide considering any provided overrides.
no setterinherited
gradient → Gradient?
A gradient to use for painting the outline, if provided.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
offset → double?
An offset to apply to the outline, in logical pixels.
finalinherited
preferPaintInterior → bool
Reports whether paintInterior is implemented.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → WxBorderSide?
The border outline's color and weight.
finalinherited
style → WxBorderStyle?
The style of the outline (e.g., solid, dashed). Can be overridden by subclasses.
finalinherited
width → double?
The desired width of the outline, in logical pixels.
finalinherited

Methods

add(ShapeBorder other, {bool reversed = false}) → ShapeBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
inherited
copyWith({WxBorderSide? side, WxBorderStyle? style, Color? color, Gradient? gradient, double? width, double? offset, BorderRadiusGeometry? corners}) → WxContinuousRectangleBorder
Returns a copy of this WxRoundedRectangleBorder with the given fields replaced with the new values.
override
getInnerPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the inner edge of the border.
override
getNonSolidPath(Path source, {TextDirection? textDirection}) → Path
Calculates the path for a non-solid outline style (e.g., dashed).
inherited
getOuterPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the outer edge of the border.
override
lerpFrom(ShapeBorder? a, double t) → ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
inherited
lerpTo(ShapeBorder? b, double t) → ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) → void
Paints the border within the given Rect on the given Canvas.
override
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
scale(double t) → ShapeBorder
Creates a copy of this border, scaled by the factor t.
inherited
toString() → String
A string representation of this object.
override

Operators

operator +(ShapeBorder other) → ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) → bool
The equality operator.
inherited